@@ -131,6 +131,8 @@ cb_show_lsof(GtkAction *action, gpointer data)
 void
 cb_about (GtkAction *action, gpointer data)
 {
+	ProcData *procdata = static_cast<ProcData*>(data);
+
 	const gchar * const authors[] = {
 		"Kevin Vandersloot",
 		"Erik Johnsson",
@@ -153,7 +155,7 @@ cb_about (GtkAction *action, gpointer data)
 	};
 
 	gtk_show_about_dialog (
-		NULL,
+		GTK_WINDOW (procdata->app),
 		"name",			_("System Monitor"),
 		"comments",		_("View current processes and monitor "
 					  "system state"),
@@ -235,7 +237,7 @@ cb_cpu_color_changed (GSMColorButton *cp, gpointer data)
 	gint i = GPOINTER_TO_INT (data);
 	GSettings *settings = g_settings_new (GSM_GSETTINGS_SCHEMA);
 
-	g_snprintf(key, sizeof key, "cpu-color%d", i);
+	g_snprintf(key, sizeof key, "cpu-color%d", i%4);
 
 	change_settings_color(settings, key, cp);
 }
@@ -430,6 +432,6 @@ cb_radio_processes(GtkAction *action, GtkRadioAction *current, gpointer data)
 
 	procdata->config.whose_process = gtk_radio_action_get_current_value(current);
 
-	g_settings_set_int (procdata->settings, "view_as",
+	g_settings_set_int (procdata->settings, "view-as",
 			      procdata->config.whose_process);
 }
